// strip off all greys lighter than this
#define GreyBase 0x6c8575
// how many pixels out of 15 are a match
#define ErrorMargin 11

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

unsigned long GetLong(FILE *source)
{
	unsigned long returnval;

	returnval = getc(source);
	returnval += getc(source) * (256);
	returnval += getc(source) * (256 << 8);
	returnval += getc(source) * (256 << 16);

	return returnval;
}

int digitcount = 0;

struct digits
{
	int digit_x;
	int digit_y;
	int accuracy;
	char *file;
} mydigits[60];

int mysortroutine(const void *a, const void *b)
{
	digits *p1 = (digits *)a;
	digits *p2 = (digits *)b;
	
	if (p1->digit_x > p2->digit_x)
		return 1;
	if (p1->digit_x < p2->digit_x)
		return -1;
	return 0;
}



int main (int argc, char **argv)
{
int c;
unsigned long colortable[257];
int inx,iny;
FILE *input;
unsigned long filelength;

char *v_[36][17];

if (argc != 2)
{
	printf("Whoisnt takes one argument: The filename of the bmp image.\n");
	printf("Convert the image using djpeg -bmp -colors 256 image.jpg new.bmp\n");
	printf("Whoisnt will output the first 4 encoded letters of the text in\n");
	printf("the bitmap.\n");
	printf("This program comes with no warranty and must be used only for\n");
	printf("accessibility or interoperability.\n");

	return 0;
}

// in the target system there is no 0 or O character to avoid user confusion.
// the error margin for "1" and "I" goes up a notch to avoid confusing one for the other

v_[0][0] = "...........    ";
v_[0][1] = "...........    ";
v_[0][2] = "  .......      ";
v_[0][3] = "    ...        ";
v_[0][4] = "    ...        ";
v_[0][5] = "    ...        ";
v_[0][6] = "    ...        ";
v_[0][7] = "    ...        ";
v_[0][8] = "    ...        ";
v_[0][9] = "    ...        ";
v_[0][10] = "    ...        ";
v_[0][11] = "    ...        ";
v_[0][12] = "... ...        ";
v_[0][13] = ".......        ";
v_[0][14] = ".......        ";

v_[1][0] = "............   ";
v_[1][1] = "............   ";
v_[1][2] = "............   ";
v_[1][3] = " .....         ";
v_[1][4] = "  .....        ";
v_[1][5] = "   .....       ";
v_[1][6] = "    .....      ";
v_[1][7] = "     .....     ";
v_[1][8] = "       ....    ";
v_[1][9] = "        ....   ";
v_[1][10] = "        ....   ";
v_[1][11] = " ...     ...   ";
v_[1][12] = " ...    ....   ";
v_[1][13] = " ..... ....    ";
v_[1][14] = "  .........    ";

v_[2][0] = " .........     ";
v_[2][1] = "...........    ";
v_[2][2] = " ...   .....   ";
v_[2][3] = "         ...   ";
v_[2][4] = "         ....  ";
v_[2][5] = "         ...   ";
v_[2][6] = "        ....   ";
v_[2][7] = "     ......    ";
v_[2][8] = "    .......    ";
v_[2][9] = "     ......    ";
v_[2][10] = "        ....   ";
v_[2][11] = "         ...   ";
v_[2][12] = " ...    ....   ";
v_[2][13] = " ..... ....    ";
v_[2][14] = "  .........    ";

v_[3][0] = "     .......   ";
v_[3][1] = "     .......   ";
v_[3][2] = "       ....    ";
v_[3][3] = "       ....    ";
v_[3][4] = "............   ";
v_[3][5] = "............   ";
v_[3][6] = " ....  ....    ";
v_[3][7] = "  ...  ....    ";
v_[3][8] = "  .... ....    ";
v_[3][9] = "   ... ....    ";
v_[3][10] = "   ........    ";
v_[3][11] = "    .......    ";
v_[3][12] = "     ......    ";
v_[3][13] = "     ......    ";
v_[3][14] = "      .....    ";

v_[4][0] = "    .......    ";
v_[4][1] = "   ..........  ";
v_[4][2] = "  ....   ..... ";
v_[4][3] = "           ... ";
v_[4][4] = "           ... ";
v_[4][5] = "           ....";
v_[4][6] = "           ... ";
v_[4][7] = "    ...   .... ";
v_[4][8] = "    .........  ";
v_[4][9] = "   .........   ";
v_[4][10] = "   .......     ";
v_[4][11] = "   ....        ";
v_[4][12] = "   ....        ";
v_[4][13] = "   ..........  ";
v_[4][14] = "   ........... ";

v_[5][0] = "     ......    ";
v_[5][1] = "    .........  ";
v_[5][2] = "   ....  ....  ";
v_[5][3] = "   ....   .... ";
v_[5][4] = "   ...     ... ";
v_[5][5] = "   ...    .... ";
v_[5][6] = "  .....   ...  ";
v_[5][7] = "  ...........  ";
v_[5][8] = "  ..........   ";
v_[5][9] = "   .......     ";
v_[5][10] = "   ...         ";
v_[5][11] = "   ....        ";
v_[5][12] = "    ....       ";
v_[5][13] = "     ..... ..  ";
v_[5][14] = "      ........ ";

v_[6][0] = "     ...       ";
v_[6][1] = "     ...       ";
v_[6][2] = "     ....      ";
v_[6][3] = "      ...      ";
v_[6][4] = "      ...      ";
v_[6][5] = "      ....     ";
v_[6][6] = "       ...     ";
v_[6][7] = "       ....    ";
v_[6][8] = "       ....    ";
v_[6][9] = "        ...    ";
v_[6][10] = "        ...    ";
v_[6][11] = " ..     ....   ";
v_[6][12] = "............   ";
v_[6][13] = "............   ";
v_[6][14] = "............   ";

v_[7][0] = "    .......    ";
v_[7][1] = "   .........   ";
v_[7][2] = "  ....   ....  ";
v_[7][3] = "  ...     ...  ";
v_[7][4] = "  ...     ...  ";
v_[7][5] = "  ....   ....  ";
v_[7][6] = "  ..... .....  ";
v_[7][7] = "   .........   ";
v_[7][8] = "   .........   ";
v_[7][9] = "  ..... .....  ";
v_[7][10] = "  ....   ....  ";
v_[7][11] = "  ...     ...  ";
v_[7][12] = "  ....   ....  ";
v_[7][13] = "   .... ....   ";
v_[7][14] = "   .........   ";

v_[8][0] = "  .....        ";
v_[8][1] = " .........     ";
v_[8][2] = "     ......    ";
v_[8][3] = "        ....   ";
v_[8][4] = "        ....   ";
v_[8][5] = "      .......  ";
v_[8][6] = "   ..........  ";
v_[8][7] = "  ...........  ";
v_[8][8] = "  ...  ......  ";
v_[8][9] = "  ...   .....  ";
v_[8][10] = " ....    ....  ";
v_[8][11] = " ....    ...   ";
v_[8][12] = "  ...   ....   ";
v_[8][13] = "  .... ....    ";
v_[8][14] = "   ........    ";

v_[9][0] = ".......   .....";
v_[9][1] = ".......   .....";
v_[9][2] = "  ...       ...";
v_[9][3] = "  ....     ....";
v_[9][4] = "   ........... ";
v_[9][5] = "   ........... ";
v_[9][6] = "   ........... ";
v_[9][7] = "    ...   ...  ";
v_[9][8] = "    .... ....  ";
v_[9][9] = "     ... ...   ";
v_[9][10] = "     ... ...   ";
v_[9][11] = "     .......   ";
v_[9][12] = "   ........    ";
v_[9][13] = "  .........    ";
v_[9][14] = "   .......     ";

v_[10][0] = "............   ";
v_[10][1] = ".............. ";
v_[10][2] = "  ............ ";
v_[10][3] = "  ...      ....";
v_[10][4] = "  ...      ....";
v_[10][5] = "  ...     .... ";
v_[10][6] = "  ............ ";
v_[10][7] = "  ...........  ";
v_[10][8] = "  ...........  ";
v_[10][9] = "  ...     ...  ";
v_[10][10] = "  ...     ...  ";
v_[10][11] = "  ...     ...  ";
v_[10][12] = " ............  ";
v_[10][13] = " ...........   ";
v_[10][14] = " ........      ";

v_[11][0] = "    ........   ";
v_[11][1] = "   ........... ";
v_[11][2] = "  .....   .... ";
v_[11][3] = " ....       .. ";
v_[11][4] = " ...           ";
v_[11][5] = "....           ";
v_[11][6] = "....           ";
v_[11][7] = "....           ";
v_[11][8] = "....           ";
v_[11][9] = " ...        ...";
v_[11][10] = " ...       ... ";
v_[11][11] = " ....     .... ";
v_[11][12] = "  ..... ...... ";
v_[11][13] = "   ........... ";
v_[11][14] = "     ......... ";

v_[12][0] = "..........     ";
v_[12][1] = "............   ";
v_[12][2] = " ............  ";
v_[12][3] = " ....     .... ";
v_[12][4] = " ....     .... ";
v_[12][5] = " ....      ... ";
v_[12][6] = " ....      ... ";
v_[12][7] = " ....      ... ";
v_[12][8] = " ....      ... ";
v_[12][9] = " ....      ... ";
v_[12][10] = " ....     .... ";
v_[12][11] = " ....    ....  ";
v_[12][12] = " ...........   ";
v_[12][13] = "...........    ";
v_[12][14] = " ........      ";

v_[13][0] = ".............. ";
v_[13][1] = ".............. ";
v_[13][2] = "  ............ ";
v_[13][3] = "  ...      ... ";
v_[13][4] = "  ...   .  ... ";
v_[13][5] = "  ...  ...  .  ";
v_[13][6] = "  ........     ";
v_[13][7] = "  ........     ";
v_[13][8] = "  ........     ";
v_[13][9] = "  ...  ... ..  ";
v_[13][10] = "  ...   . .... ";
v_[13][11] = "  ...     .... ";
v_[13][12] = ".............. ";
v_[13][13] = ".............. ";
v_[13][14] = " ............. ";

v_[14][0] = " .........     ";
v_[14][1] = " .........     ";
v_[14][2] = "   .....       ";
v_[14][3] = "   ...         ";
v_[14][4] = "   ...   .     ";
v_[14][5] = "   ...  ...    ";
v_[14][6] = "   ........    ";
v_[14][7] = "   ........    ";
v_[14][8] = "   ........    ";
v_[14][9] = "   ...  ...  . ";
v_[14][10] = "   ...      ...";
v_[14][11] = "   ...      ...";
v_[14][12] = "  .............";
v_[14][13] = " ..............";
v_[14][14] = " ..............";

v_[15][0] = "    .........  ";
v_[15][1] = "  ............ ";
v_[15][2] = "  .....   .... ";
v_[15][3] = " ....      ... ";
v_[15][4] = " ...       ... ";
v_[15][5] = " ...   ........";
v_[15][6] = "....   ........";
v_[15][7] = "....           ";
v_[15][8] = " ...           ";
v_[15][9] = " ...           ";
v_[15][10] = " ...       ... ";
v_[15][11] = "  ...      ... ";
v_[15][12] = "  .....  ..... ";
v_[15][13] = "   ........... ";
v_[15][14] = "    .......... ";

v_[16][0] = "...... ....... ";
v_[16][1] = "...... ....... ";
v_[16][2] = " ...     ...   ";
v_[16][3] = " ...     ...   ";
v_[16][4] = " ...     ...   ";
v_[16][5] = " ...     ...   ";
v_[16][6] = " ...........   ";
v_[16][7] = " ...........   ";
v_[16][8] = " ...........   ";
v_[16][9] = " ...     ...   ";
v_[16][10] = " ...     ...   ";
v_[16][11] = " ...     ...   ";
v_[16][12] = ".....   .....  ";
v_[16][13] = "...... ......  ";
v_[16][14] = "...... ......  ";

v_[17][0] = " ...........   ";
v_[17][1] = " ...........   ";
v_[17][2] = "   .......     ";
v_[17][3] = "     ...       ";
v_[17][4] = "     ...       ";
v_[17][5] = "     ...       ";
v_[17][6] = "     ...       ";
v_[17][7] = "     ...       ";
v_[17][8] = "     ...       ";
v_[17][9] = "     ...       ";
v_[17][10] = "     ...       ";
v_[17][11] = "     ...       ";
v_[17][12] = "  .........    ";
v_[17][13] = " ...........   ";
v_[17][14] = " ...........   ";

v_[18][0] = "   ......      ";
v_[18][1] = "..........     ";
v_[18][2] = ".....  ....    ";
v_[18][3] = "...     ...    ";
v_[18][4] = "...     ....   ";
v_[18][5] = "...     ....   ";
v_[18][6] = "...     ....   ";
v_[18][7] = "        ....   ";
v_[18][8] = "        ....   ";
v_[18][9] = "        ....   ";
v_[18][10] = "        ....   ";
v_[18][11] = "        ....   ";
v_[18][12] = "     ......... ";
v_[18][13] = "    ...........";
v_[18][14] = "    .......... ";

v_[19][0] = "........   ....";
v_[19][1] = "........  .....";
v_[19][2] = "  ....    ...  ";
v_[19][3] = "  ...   .....  ";
v_[19][4] = "  ...   ....   ";
v_[19][5] = "  ....  ....   ";
v_[19][6] = "  .........    ";
v_[19][7] = "  ........     ";
v_[19][8] = "  .......      ";
v_[19][9] = "  ... ....     ";
v_[19][10] = "  ...  ....    ";
v_[19][11] = "  ...   ....   ";
v_[19][12] = " ...... ...... ";
v_[19][13] = "...............";
v_[19][14] = " ......  ..... ";

v_[20][0] = " ..............";
v_[20][1] = " ..............";
v_[20][2] = "  .............";
v_[20][3] = "    ...    ....";
v_[20][4] = "    ...    ....";
v_[20][5] = "    ...     ...";
v_[20][6] = "    ...        ";
v_[20][7] = "    ...        ";
v_[20][8] = "    ...        ";
v_[20][9] = "    ...        ";
v_[20][10] = "    ...        ";
v_[20][11] = "    ...        ";
v_[20][12] = "  .......      ";
v_[20][13] = "..........     ";
v_[20][14] = " ........      ";

v_[21][0] = ".......   .....";
v_[21][1] = ".......   .....";
v_[21][2] = "  ...       ...";
v_[21][3] = "  ...       ...";
v_[21][4] = "  ...  ...  ...";
v_[21][5] = "  ... ..... ...";
v_[21][6] = "  ... ..... ...";
v_[21][7] = "  ... .........";
v_[21][8] = "  ...... ......";
v_[21][9] = "  ...... ......";
v_[21][10] = "  .....   .....";
v_[21][11] = "  .....   .....";
v_[21][12] = " ......    ....";
v_[21][13] = "......     ....";
v_[21][14] = " .....     ....";

v_[22][0] = ".......   .... ";
v_[22][1] = ".......  ..... ";
v_[22][2] = " ....    ..... ";
v_[22][3] = " ....   ...... ";
v_[22][4] = " ....   ...... ";
v_[22][5] = " ....  ....... ";
v_[22][6] = " .... ........ ";
v_[22][7] = " .... ... .... ";
v_[22][8] = " ........ .... ";
v_[22][9] = " .......  .... ";
v_[22][10] = " ......   .... ";
v_[22][11] = " ......   .... ";
v_[22][12] = "......   ..... ";
v_[22][13] = "......  .......";
v_[22][14] = ".....   .......";

v_[23][0] = ".........      ";
v_[23][1] = "..........     ";
v_[23][2] = "  ......       ";
v_[23][3] = "  ...          ";
v_[23][4] = "  ...          ";
v_[23][5] = "  ........     ";
v_[23][6] = "  ..........   ";
v_[23][7] = "  ...........  ";
v_[23][8] = "  ...     ...  ";
v_[23][9] = "  ...     .... ";
v_[23][10] = "  ...     .... ";
v_[23][11] = "  ...     ...  ";
v_[23][12] = " ............  ";
v_[23][13] = "............   ";
v_[23][14] = " ........      ";

v_[24][0]  = "   ........... ";
v_[24][1]  = "   ............";
v_[24][2]  = "    .....      ";
v_[24][3]  = "    .......    ";
v_[24][4]  = "   .........   ";
v_[24][5]  = "  ..... .....  ";
v_[24][6]  = " ....     .... ";
v_[24][7]  = " ...       ... ";
v_[24][8]  = " ...       ....";
v_[24][9]  = "....       ....";
v_[24][10] = "...         ...";
v_[24][11] = "....       ....";
v_[24][12] = "....       ....";
v_[24][13] = " ....     .....";
v_[24][14] = " ....     .... ";

v_[25][0] = "........    ...";
v_[25][1] = "........   ....";
v_[25][2] = "  ....    .... ";
v_[25][3] = "  ...    ....  ";
v_[25][4] = "  ...   .....  ";
v_[25][5] = "  ...  .....   ";
v_[25][6] = "  .........    ";
v_[25][7] = "  ..........   ";
v_[25][8] = "  ...   .....  ";
v_[25][9] = "  ...     ...  ";
v_[25][10] = "  ...     .... ";
v_[25][11] = "  ...     ...  ";
v_[25][12] = " ............  ";
v_[25][13] = "............   ";
v_[25][14] = " ........      ";

v_[26][0] = "  ..........   ";
v_[26][1] = "  ............ ";
v_[26][2] = "  .....   .... ";
v_[26][3] = "  ....     ....";
v_[26][4] = "  ...      ....";
v_[26][5] = "          .... ";
v_[26][6] = "       ....... ";
v_[26][7] = "    .........  ";
v_[26][8] = "   .......     ";
v_[26][9] = "   ....        ";
v_[26][10] = "   ...     ... ";
v_[26][11] = "   ...     ... ";
v_[26][12] = "    .... ..... ";
v_[26][13] = "    .......... ";
v_[26][14] = "      ........ ";

v_[27][0] = "   .........   ";
v_[27][1] = "   .........   ";
v_[27][2] = "     .....     ";
v_[27][3] = "      ...      ";
v_[27][4] = "      ...      ";
v_[27][5] = "      ...      ";
v_[27][6] = "      ...      ";
v_[27][7] = "      ...      ";
v_[27][8] = " ..   ...   .. ";
v_[27][9] = " ...  ...  ... ";
v_[27][10] = " ...  ...  ... ";
v_[27][11] = " ...  ...  ... ";
v_[27][12] = " ............. ";
v_[27][13] = " ............. ";
v_[27][14] = " ............. ";

v_[28][0] = "    ......     ";
v_[28][1] = "   .........   ";
v_[28][2] = "  .....  ...   ";
v_[28][3] = "  ...     ...  ";
v_[28][4] = "  ...     ...  ";
v_[28][5] = " ....     .... ";
v_[28][6] = " ....     .... ";
v_[28][7] = " ....     .... ";
v_[28][8] = " ....     .... ";
v_[28][9] = " ....     .... ";
v_[28][10] = " ....     .... ";
v_[28][11] = " ....     .... ";
v_[28][12] = " .....   ..... ";
v_[28][13] = "....... .......";
v_[28][14] = "....... .......";

v_[29][0] = "      ...      ";
v_[29][1] = "     .....     ";
v_[29][2] = "     .....     ";
v_[29][3] = "    .......    ";
v_[29][4] = "    ... ...    ";
v_[29][5] = "    ... ...    ";
v_[29][6] = "   .... ....   ";
v_[29][7] = "   ...   ...   ";
v_[29][8] = "  ....   ....  ";
v_[29][9] = "  ...     ...  ";
v_[29][10] = "  ...     ...  ";
v_[29][11] = " ....     .... ";
v_[29][12] = ".....     .....";
v_[29][13] = "....... .......";
v_[29][14] = "......   ......";

v_[30][0] = "   ....   .... ";
v_[30][1] = "   ....   .... ";
v_[30][2] = "   ....   .... ";
v_[30][3] = "   ..... ..... ";
v_[30][4] = "  ...... ......";
v_[30][5] = "  ...... ......";
v_[30][6] = "  .............";
v_[30][7] = "  ... ..... ...";
v_[30][8] = "  ... ..... ...";
v_[30][9] = "  ... ..... ...";
v_[30][10] = "  ...  ...  ...";
v_[30][11] = "  ...       ...";
v_[30][12] = " ......   .....";
v_[30][13] = "........ ......";
v_[30][14] = " ......   .....";

v_[31][0] = ".......  ......";
v_[31][1] = "....... .......";
v_[31][2] = ".....     .... ";
v_[31][3] = "  ....   ....  ";
v_[31][4] = "   .... ....   ";
v_[31][5] = "    .......    ";
v_[31][6] = "     .....     ";
v_[31][7] = "     .....     ";
v_[31][8] = "     .....     ";
v_[31][9] = "    .......    ";
v_[31][10] = "   .... ....   ";
v_[31][11] = "  ....   ....  ";
v_[31][12] = " .....   ..... ";
v_[31][13] = "....... .......";
v_[31][14] = " .....   ..... ";

v_[32][0] = "   .........   ";
v_[32][1] = "   .........   ";
v_[32][2] = "     .....     ";
v_[32][3] = "      ...      ";
v_[32][4] = "      ...      ";
v_[32][5] = "      ...      ";
v_[32][6] = "      ...      ";
v_[32][7] = "     .....     ";
v_[32][8] = "    .......    ";
v_[32][9] = "    ... ...    ";
v_[32][10] = "   .... ....   ";
v_[32][11] = "  ....   ....  ";
v_[32][12] = " .....   ..... ";
v_[32][13] = "....... .......";
v_[32][14] = " .....   ..... ";

v_[33][0] = ".............  ";
v_[33][1] = ".............  ";
v_[33][2] = ".............  ";
v_[33][3] = " ....    ....  ";
v_[33][4] = "  ....   ....  ";
v_[33][5] = "   ....   ..   ";
v_[33][6] = "    ....       ";
v_[33][7] = "    ....       ";
v_[33][8] = "     ....      ";
v_[33][9] = " ...  ....     ";
v_[33][10] = " ...   ....    ";
v_[33][11] = " ...   ....    ";
v_[33][12] = " ...........   ";
v_[33][13] = " ...........   ";
v_[33][14] = " ...........   ";

	int matrix[17][17];
	int mainmatrix[51][126];
	char *alphabet[] = {"1","2","3","4","5","6","7","8","9","A","B","C","D","E","F","G","H","I","J","K","L","M","N","P","Q","R","S","T","U","V","W","X","Y","Z",NULL};
	int lcount = 0;
	int j = 0;
	
	for (j = 0; j < 36; j++)
	{
		if (alphabet[j] == NULL)
			break;

		for (iny = 0; iny < 15; iny++)
		{
			for (inx = 0; inx < 15; inx++)
			{
				if (v_[j][iny][inx] == ' ')
				{
					matrix[inx][iny] = 0;
				}
				else
				{
					matrix[inx][iny] = 1;
				}
			}
		}

		if ((input=fopen(argv[1],"r+b"))!=NULL)
		{
			fseek(input,0L,SEEK_END);
			filelength=ftell(input);
			fseek(input,0L,SEEK_SET);

			fseek(input,0x36,SEEK_SET);

			int zx;

			for (zx = 0; zx < 256; zx++)
			{
				colortable[zx] = GetLong(input);
				if (colortable[zx] > GreyBase)
					colortable[zx] = 0xffffff;
			}

			int start = 1078;

			fseek(input,1078,SEEK_SET);

			int myx,myy;

			for (myy = 0; myy < 50; myy++)
			{
				for (myx = 0; myx < 125; myx++)
				{
					c = getc(input);
					if (colortable[c] != 0xffffff)
					{
						mainmatrix[myy][myx] = 1;
					}
					else
					{
						mainmatrix[myy][myx] = 0;
					}
				}
				while ((ftell(input) - start) % 8)
				{
					getc(input);
				}
			}

			int ay;
			int found = 0;
			int myouterx;
			int myoutery;

			for (myoutery = 0; myoutery < 26; myoutery++)
			{
				for (myouterx = 0; myouterx < 126; myouterx++)
				{
					int accuracy = 0;
					for (ay = 0; ay < 15; ay++)
					{
						int linematch = 0;
		
						for (myx = myouterx; myx <= myouterx+15; myx++)
						{
							if ((mainmatrix[ay+myoutery][myx] == matrix[myx - myouterx][ay]))
							{
								linematch++;
							}
						}
						int margin;
	
						// special case for "I" and "1"
						if (j == 17 || j == 0)
							margin = ErrorMargin + 1;
						else
							margin = ErrorMargin;

						if (linematch > margin)
						{
							found = 1;
						}
						else
						{
							found = 0;
							break;
						}
					}
					if (found)
					{
						int lfound;
		
						lfound = 0;
						for (int lc = 0; lc < digitcount; lc++)
						{
							if (mydigits[lc].digit_x ==  myouterx)
							{
								lfound = 1;
							}
						}
						if (!lfound)
						{
							mydigits[digitcount].digit_x = myouterx;
							mydigits[digitcount].accuracy = accuracy;
							mydigits[digitcount].digit_y = myoutery;
							mydigits[digitcount].file = alphabet[j];
							digitcount++;
							// advance to next character so we don't scan it twice
							myouterx+=14;
							found = 0;
						}
					}
				}
			}
		}
		else
			return 1;
	}

	qsort(mydigits,digitcount, sizeof(digits), mysortroutine);

	if (digitcount > 4)
		digitcount = 4;

	for (int i = 0; i < digitcount; i++)
	{
		if ((mydigits[i].digit_y != 19) && (digitcount > 6))
			continue;
		if (mydigits[i].file)
			printf("%s",mydigits[i].file);
		else
		{
			printf(".");
			return 1;
		}
	}
	printf("\n");
	return 0;
}

